@@ -85,7 +85,7 @@ extern "C"
         out << footer << std::endl;
     }
 
-    void* SaveTimelineMC(void* lt, const char *filename, const char *header, const char* footer, void *ptr, int exponent, uint64_t startgen) {
+    void SaveTimelineMC(void* lt, const char *filename, const char *header, const char* footer, void *ptr, int exponent) {
 
         auto lab = reinterpret_cast<apg::lifetree_abstract<uint32_t>*>(lt);
 
@@ -100,6 +100,7 @@ extern "C"
             hnodes.push_back(emptypat.coerce(*(patarray[i])));
             i += 1;
         }
+        uint64_t startgen = (reinterpret_cast<uint64_t*>(ptr))[i+1];
 
         std::ofstream out(filename);
         lab->write_macrocell_header(out);
@@ -144,16 +145,17 @@ extern "C"
         return new(std::nothrow) apg::pattern(lab, vbw, std::string(rule));
     }
 
-    void* AdvancePattern(void* pat, int numgens, uint64_t exponent) {
+    void* AdvancePattern(void* pat, int numgens, uint32_t exponent) {
         auto ppat = reinterpret_cast<apg::pattern*>(pat);
         return new(std::nothrow) apg::pattern(ppat->advance2(numgens, exponent));
     }
 
-    void* GetSolidForPattern(void* pat, uint64_t state, uint64_t exponent) {
+    void* GetSolidForPattern(void* pat, uint32_t state, uint32_t exponent) {
+        uint64_t truestate = ((uint64_t) state) << exponent;
         auto ppat = reinterpret_cast<apg::pattern*>(pat);
         auto lab = ppat->getlab();
         uint64_t depth = ppat->gethnode().depth;
-        return new(std::nothrow) apg::pattern(lab, lab->solid(depth, state << exponent), ppat->getrule());
+        return new(std::nothrow) apg::pattern(lab, lab->solid(depth, truestate), ppat->getrule());
     }
 
     void* GetSemisolidForPattern(void* pat, int flags) {
@@ -168,7 +170,7 @@ extern "C"
         return new(std::nothrow) apg::pattern(ppat->bitshift(shift));
     }
 
-    void* ShiftPattern(void* pat, int x, int y, uint64_t exponent) {
+    void* ShiftPattern(void* pat, int x, int y, uint32_t exponent) {
         auto ppat = reinterpret_cast<apg::pattern*>(pat);
         return new(std::nothrow) apg::pattern(ppat->shift(x, y, exponent));
     }
