@@ -25,6 +25,17 @@ class Lifetree(object):
 
         session.lifetree_ptrs.add(self.ptr)
 
+    def save_timeline(self, patterns, filename, header="", footer="", exponent=0, startgen=0):
+
+        import numpy as np
+        n = len(patterns) + 2
+        frames = np.zeros((n,), dtype=np.uint64, order='C')
+        for (i, p) in enumerate(patterns):
+            frames[i] = p.ptr[0]
+        frames[n-1] = startgen
+        filename = os.path.abspath(filename)
+        self.lifelib('SaveTimelineMC', self.ptr, filename, header, footer, frames, exponent)
+
     def unify(self, *patterns):
 
         output = self.pattern()
