@@ -116,7 +116,7 @@ namespace apg {
             d |= (((uint64_t) digest[2*j+17]) << 8*j);
         }
 
-        if ((symmetry == "C1") || (symmetry == "D2_x")) {
+        if ((symmetry == "C1") || (symmetry == "G1") || (symmetry == "D2_x")) {
             #ifdef __AVX512F__
             bw.world[std::pair<int32_t, int32_t>(1, 2)] = b;
             bw.world[std::pair<int32_t, int32_t>(2, 2)] = a;
@@ -229,7 +229,12 @@ namespace apg {
             rot3 = false;
         }
 
-        // std::cout << inflations << " " << symmetry << std::endl;
+        if (symmetry[0] == 'G') {
+            symmetry = "C" + symmetry.substr(1);
+        } else if (symmetry[0] == 'H') {
+            symmetry = "D" + symmetry.substr(1);
+        }
+
         bitworld bw = hashsoup_inner(prehash, symmetry);
 
         if (rot3) {
